@@ -9,24 +9,25 @@
 
 
 ;;(newvar expr) will add in a sorted manner all the new variables to the beginning
-;;of the varlist.  
+;;of the varlist.
 
 (defvar *genpairs* nil)
+
 (defun reset-vgp ()  (setq *genpairs* nil  *genvar*  nil  *varlist* nil)
-       (setq *xxx* 
+       (setq *xxx*
 	     (let ((*nopoint t) *print-radix*)
-	       (sloop for i from 1 to 30 collecting
-		     (add-newvar (intern (format nil "$X~A" i))))))
+	       (loop for i from 1 to 30 collecting
+		      (add-newvar (intern (format nil "$X~A" i))))))
        'done)
 
 
-(defun show-vgp ()(show 	*genpairs* genpairs	*genvar* genvar  	*varlist*
-				varlist))
+(defun show-vgp ()
+  (show *genpairs* genpairs *genvar* genvar *varlist* varlist))
+
 (defvar vlist nil)
 
-
 (defun put-tellrat-property (va the-gensym)
-  (sloop for v in tellratlist
+  (loop for v in tellratlist
 	when (equal va (car v))
 	do (putprop the-gensym (cdr v) 'tellrat)))
 
@@ -34,11 +35,11 @@
 (defun poly-ncmul1 (mon   poly  mon1 &aux monom new-monom tem gen-sym)
   (cond ((null mon)(setq mon 1))
 	((null mon1) (setq mon1 1)))
-  (cond ((not (polynomialp poly))(break t)))
-  
+  (cond ((not (affine-polynomialp poly))(break t)))
+
   (cond ((and (numberp mon)(numberp mon1))
 	 (n* poly (n* mon mon1)))
-        ((or (numberp poly)($scalarp (setq monom (get (car poly) 'disrep))))
+	((or (numberp poly)($scalarp (setq monom (get (car poly) 'disrep))))
 	 (setq gen-sym (add-newvar (setq monom (ncmul* mon mon1))))
 	 (n* (list gen-sym 1 1) ;;(assolike monom *genpairs*);;might be long list to look in
 	     poly))
@@ -47,27 +48,27 @@
 		  (cond ((and (eq (second poly) 1)(eq (fourth poly) 0))
 			 (poly-ncmul1 mon (fifth poly) mon1))
 			((eq (second poly) 1) 0)
-			(t (ferror "There is a bad order in nc polynomial ~A" poly))))
+			(t (merror "There is a bad order in nc polynomial ~A" poly))))
 		 (t
 		  (setq gen-sym (add-newvar new-monom))
 		  (cond ((and (eq (second poly) 1)(eq (fourth poly) 0))
 			 (setq tem (poly-ncmul1 mon (fifth poly) mon1))
 			 (cond
 			   ((eq tem 0)(list gen-sym 1 (third poly)))
-			   (t 
+			   (t
 			    (list gen-sym 1 (third poly) 0
-				   tem)))) 
+				   tem))))
 			((eq (second poly) 1)
 			 (list gen-sym 1 (third poly)))
-			(t (ferror "There is a bad order in nc polynomial ~A" poly))))))))
+			(t (merror "There is a bad order in nc polynomial ~A" poly))))))))
 
 
 ;the above checks for terms in the radical and zero simplifications.
 ;(defun poly-ncmul1 (mon   poly  mon1 &aux monom new-monom gen-sym)
 ;  (cond ((null mon)(setq mon 1))
 ;	((null mon1) (setq mon1 1)))
-;  (cond ((not (polynomialp poly))(break t)))
-;  
+;  (cond ((not (affine-polynomialp poly))(break t)))
+;
 ;  (cond ((and (numberp mon)(numberp mon1))
 ;	 (n* poly (n* mon mon1)))
 ;        ((or (numberp poly)($scalarp (setq monom (get (car poly) 'disrep))))
@@ -75,28 +76,28 @@
 ;	 (n* (list gen-sym 1 1) ;;(assolike monom *genpairs*);;might be long list to look in
 ;	     poly))
 ;	(t (setq new-monom (ncmul* mon monom mon1))
-;	   
+;
 ;	   (setq gen-sym (add-newvar new-monom))
 ;	   (cond ((and (eq (second poly) 1)(eq (fourth poly) 0))
 ;		  (list gen-sym 1 (third poly) 0 (poly-ncmul1 mon (fifth poly) mon1)))
 ;		 ((eq (second poly) 1)
 ;		  (list gen-sym 1 (third poly)))
-;		 (t (ferror "There is a bad order in nc polynomial ~A" poly))))))
+;		 (t (merror "There is a bad order in nc polynomial ~A" poly))))))
 ;(defun new-rat-ncmul (a nc-rat-expr c)
 ;  (cons (poly-ncmul1 a (num nc-rat-expr) c) (denom nc-rat-expr)))
-  
+
 (defun poly-ncmul (&rest ll)
   "broken"
-  (sloop for v in ll when (not (polynomialp v))do (break t))
+  (loop for v in ll when (not (affine-polynomialp v))do (break t))
   (cond ((null ll) 1)
 	((eq (length ll) 1) (car ll))
 	((numberp (car ll))(n* (car ll) (apply 'poly-ncmul (cdr ll))))
-	((polynomialp (car ll))
+	((affine-polynomialp (car ll))
 	      (apply
 				  'poly-ncmul (poly-ncmul1 1 (car ll) (second ll))
 				  (nthcdr 2 ll)))
-	((polynomialp (second ll))
-	 (cond ((polynomialp (third ll)) (ferror "poly-ncmul can't have two 'polynomialp objects in its arg yet"))
+	((affine-polynomialp (second ll))
+	 (cond ((affine-polynomialp (third ll)) (merror "poly-ncmul can't have two 'affine-polynomialp objects in its arg yet"))
 	       (t (apply 'poly-ncmul
 				 (poly-ncmul1 (car ll)  (second ll) (third ll))
 				 (nthcdr 3 ll)))))))
@@ -104,7 +105,7 @@
 (defun reset-gen () (setq genvar nil varlist nil genpairs nil))
 
 (defun show-vg (&optional (varl *varlist* ) (genv *genvar*))
-  (sloop for v in varl
+  (loop for v in varl
 	for w in genv
 	do (format t "~%~A ~A disrep ~A value ~A" w v (get w 'disrep) (symbol-value w))
 	when (not (equal (get w 'disrep) v))do (format t" **** bad disrep ***")
@@ -113,51 +114,48 @@
 
 
 (defun last2 (a-list)
-  (sloop for v on a-list
+  (loop for v on a-list
 	while (cddr v)
 	finally (return v)))
 
 (defun lastn (n a-list)
-  (sloop for v on a-list
+  (loop for v on a-list
 	while (nthcdr n v)
 	finally (return v)))
 
-  
+
 
 (defun choose (m n)
- (quotient (factorial m) (f* (factorial n) (factorial (f- m n)))))
+ (quotient (factorial m) (* (factorial n) (factorial (- m n)))))
+
 (defun polynomial-ring-1-1-1  (deg)
-	(choose (f+ deg 2) deg))
-
-
-(defun three-times-n (n) (f* 3 n))
-
-
+	(choose (+ deg 2) deg))
 
+(defun three-times-n (n) (* 3 n))
 
 (defun list-equations1 (expr)
   "converts a single macsyma equation into a lisp list of cons's suitable for sublis"
   (cond ((and (listp (car expr))(eq (caar expr) 'mequal))(setq expr (cdr expr)))
-	(t (ferror "not a equation ~A " expr)))
+	(t (merror "not a equation ~A " expr)))
   (cond ((atom (first expr))(list (cons (first expr) (second expr))))
-	((memq (caar (first expr)) '($matrix mlist))
-	 (sloop for v in (cdr (first expr))
+	((member (caar (first expr)) '($matrix mlist) :test #'eq)
+	 (loop for v in (cdr (first expr))
 	       for w in (cdr (second expr))
 	       appending (list-equations1 (list v w))))))
 
 (defun list-equations-macsyma1 (expr)
   (cond ((and (listp (car expr))(eq (caar expr) 'mequal))
 	 (cond ((atom (second expr)) (list expr))
-	       ((not (memq (caar (second expr)) '($matrix mlist))) (list expr))
+	       ((not (member (caar (second expr)) '($matrix mlist) :test #'eq)) (list expr))
 	       (t (setq expr (cdr expr))
-		  (cond ((memq (caar (first expr)) '($matrix mlist))
+		  (cond ((member (caar (first expr)) '($matrix mlist) :test #'eq)
 			 (cond ((or (atom (second expr))(not (eql (caar (first expr))
 							    (caar (second expr)))))
-				(sloop for v in (cdr (first expr))
+				(loop for v in (cdr (first expr))
 				      appending (list-equations-macsyma1
 						  (list '(mequal) v (second expr)))))
 			       (t
-			 (sloop for v in (cdr (first expr))
+			 (loop for v in (cdr (first expr))
 			       for w in (cdr (second expr))
 			       appending (list-equations-macsyma1
 					   (list '(mequal) v w))))))))))))
@@ -166,23 +164,23 @@
 (defun $list_factors(poly)
   (cond
     ((atom poly ) poly)
-    ((MBAGP poly) (CONS (CAR poly) (MAPCAR #'$list_factors (CDR poly))))
+    ((mbagp poly) (cons (car poly) (mapcar #'$list_factors (cdr poly))))
     ((eq (caar poly) 'mtimes)
      (cons '(mlist) (cdr poly)))
     (t poly)))
- 
+
 (defun $list_equations (a-list)
   (check-arg a-list '$listp "macsyma list")
-  (sloop for v in (cdr a-list)
+  (loop for v in (cdr a-list)
 	appending (list-equations-macsyma1 v) into tem
 	finally (return (cons '(mlist) tem))))
-	
+
 (defun $sub_list (eqns expr)
   (check-arg eqns '$listp "macsyma list")
   (setq eqns ($list_equations eqns))
   ($sublis eqns expr))
 
-;  (setq eqns (sloop for v in (cdr eqns)
+;  (setq eqns (loop for v in (cdr eqns)
 ;	appending (list-equations1 v) ))
 ;  (new-sublis eqns expr))
 
@@ -193,18 +191,15 @@
 	  (t (setq answer (sublis subs expr))(cond (rat-form ($new_rat answer))
 						   (t (meval* expr))))))
 
-
-
-
 (defun remove-from-*genpairs* (expr)
-  (setq *genvar* (zl-DELETE (get-genvar expr) *genvar*))
-  (sloop for v in *genpairs*
+  (setq *genvar* (delete (get-genvar expr) *genvar* :test #'equal))
+  (loop for v in *genpairs*
 	for i from 0
 	when (equal (car v) expr)
 	do
 	(cond ((eq i 0)(setq *genpairs* (cdr *genpairs*)))
-	      (t (setq *genpairs* (zl-DELETE v *genpairs*)))))
-  (setq *varlist* (zl-DELETE expr *varlist*)))
+	      (t (setq *genpairs* (delete v *genpairs* :test #'equal)))))
+  (setq *varlist* (delete expr *varlist* :test #'equal)))
 
 ;
 ;(defmacro must-replacep (symbol-to-set rat-poly)
@@ -220,10 +215,10 @@
   (cdr ($new_rat (meval* tem))))
 
 (defvar *fake-rat* '(mrat nil nil nil))
-; 
+;
 ;(defun sh (expr)
 ;  (cond ((numberp expr)(displa expr))
-;	((polynomialp expr)(displa (cons  *fake-rat* (cons expr 1))))
+;	((affine-polynomialp expr)(displa (cons  *fake-rat* (cons expr 1))))
 ;	((rational-functionp expr)(displa (cons *fake-rat* expr)))
 ;	(t (displa expr)))
 ;  expr)
@@ -231,12 +226,12 @@
 
 (defvar $homework_done '((mlist)))
 (defquote $homework ( a-list &aux answer work )
-  (sloop for v in (cdr a-list)
+  (loop for v in (cdr a-list)
 	when (symbolp v)
 	do (setq $homework_done (append $homework_done (list  (setq work (meval* v)) )))
 	else
 	do (setq $homework_done  (append $homework_done (list  (setq work  v))))
-	do (format t "~%Working on ...") (displa work) 
+	do (format t "~%Working on ...") (displa work)
 	do  (setq $homework_done (append $homework_done (list  (setq answer(meval* work)))))
 	(displa answer))
   $homework_done)
@@ -247,54 +242,55 @@
 (defun $unipotent_invariant_vectors (representation n1 n2 &aux answer eqns)
   "representation should take two arguments a (size n1) and b (size n2) where a is
    in GLn1 and b is a macsyma list of length n2. It returns the general vector b left invariant  by the upper triangular (unipotent)  matrices."
-  (sloop for i from 1 below n1 
+  (loop for i from 1 below n1
      appending (cdr ($list_equations
 		      (list '(mlist)
 			    (list '(mequal)
-				  (mfuncall representation ($eij n1 i (f1+ i))
+				  (mfuncall representation ($eij n1 i (1+ i))
 					    ($firstn n2 $aaaa))
 				  ($firstn n2 $aaaa))))) into tem
     finally (setq answer ($fast_linsolve (setq eqns (cons '(mlist) tem)) ($firstn n2 $aaaa))))
 
   ($separate_parameters ($sublis answer ($firstn n2 $aaaa))))
 (defun $matrix_from_list (a-list &aux tem)
-  (let ((n (fixr (setq tem (expt   ($length a-list) .5)))))
+  (let ((n (round (setq tem (expt ($length a-list) .5)))))
     (cond ((eq (expt  n 2) ($length a-list)) 'fine)
-	  (t (ferror "The length of list is not a square")))
+	  (t (merror "The length of list is not a square")))
     (setq a-list (cdr a-list))
-    (sloop while a-list
-	  collecting (cons '(mlist) (firstn n a-list)) into tem1
+    (loop while a-list
+	  collecting (cons '(mlist) (subseq a-list 0 n)) into tem1
 	  do (setq a-list (nthcdr n a-list))
 	  finally (return  (cons '($matrix ) tem1)))))
 
 (defun kronecker-row-product (a b)
-  (sloop for v in (cdr b)
+  (loop for v in (cdr b)
 	appending
-	(sloop for w in (cdr a)
-		 collecting (mul* v w) )
-	into tem 
+	(loop for w in (cdr a)
+		 collecting (mul* v w))
+	into tem
 	finally (return (cons '(mlist) tem))))
 
 (defun $kronecker_product (m n)
-  (sloop for row in (cdr n)
+  (loop for row in (cdr n)
 	appending
-	(sloop for rowm in (cdr m)
+	(loop for rowm in (cdr m)
 	      collecting (kronecker-row-product rowm row))
 	into tem1
 	finally (return (cons '($matrix) tem1))))
 
 (defun $standard_rep (mat v)($list_matrix_entries(ncmul* mat v)))
+
 (defun $unlist_matrix_entries (vect &optional size  )
   (cond (size nil)
-	(t (setq size (fixr (expt  (length vect) .5)))))
+	(t (setq size (round (expt  (length vect) .5)))))
   (setq vect (cdr vect))
-  (sloop for i below size
-	collecting (cons '(mlist) (firstn size vect)) into tem
+  (loop for i below size
+	collecting (cons '(mlist) (subseq vect 0 size)) into tem
 	do (setq vect (nthcdr  size vect))
 	finally (return (cons '($matrix) tem))))
 
 (defun sub-list (a-list expr)
-  (sloop for v on a-list by 'cddr
+  (loop for v on a-list by 'cddr
 	collecting `((mequal) ,(car v) ,(second v)) into tem
 	finally (return ($sub_list (cons '(mlist) tem) expr))))
 (defmacro defrep (name argu &rest body &aux v mat)
@@ -306,8 +302,8 @@
 	    (sub-list (list (first info) ,mat
 			    (second info) ,v)
 		      (third info)))
-	   (t 	 (setq gen-mat ($general_matrix (f1- (length (second ,mat))) '$p))
-		 (setq gen-vector (firstn (length ,v) $aaaa))
+	   (t	 (setq gen-mat ($general_matrix (1- (length (second ,mat))) '$p))
+		 (setq gen-vector (subseq $aaaa 0 (length ,v)))
 		 (setq image (progn ,@body))
 		 (putprop  '$tensor4 (list gen-mat gen-vector image) 'representation)
 		 ($tensor4 mat v)))))
@@ -317,13 +313,13 @@
 
 (defun $tensor4 (mat v &aux info gen-mat gen-vector image)
   (cond ((setq info (get '$tensor4 'representation))
-	 
+
 	 (sub-list (list (first info) mat
 			 (second info) v)
 		   (third info)))
-	(t 	 (setq gen-mat ($general_matrix (f1- (length (second mat))) '$p))
-		 (setq gen-vector (firstn (length v) $aaaa))
-		 
+	(t	 (setq gen-mat ($general_matrix (1- (length (second mat))) '$p))
+		 (setq gen-vector (subseq $aaaa 0 (length v)))
+
 		 (setq image ($tensor_product_representation
 			       '$tensor2
 			       4
@@ -349,7 +345,7 @@
 			 mat v))
 
 (defun $tensor3 (mat v)($tensor_product_representation
-			 
+
 			 '$tensor2
 			 4
 			 '$standard_rep
@@ -366,12 +362,12 @@
 			 mat v))
 
 (defun $tensor3 (mat v)($tensor_product_representation
-                        
+
 			 '$tensor2
 			 9
 			'$standard_rep
-			 3 
-			 
+			 3
+
 			 mat v))
 
 (defun $tensor3 (mat v)($tensor_product_representation
@@ -386,7 +382,7 @@
 
 (defun $sum5_standard_rep(mat v)
   (let ((size ($length mat)))
-    (sloop for i below 5
+    (loop for i below 5
 	  appending (cdr ($standard_rep mat ($firstn size v))) into tem
 	  do (setq v (cons '(mlist) (nthcdr size (cdr v))))
 	  finally (return (cons '(mlist) tem)))))
@@ -403,31 +399,31 @@
 ;  e2^Ve2^Ve2]
 
 
-;;the first two are in the above representation and the second two are for reversed 
+;;the first two are in the above representation and the second two are for reversed
 ;;indexing where the subscripts vary the fastest at the right.(as usual in zeta lisp)
 
 (defun list-ind-to-tensor-ind (dimv tensor-power ind)
-  (setq ind (f1- ind))
-  (sloop for i below tensor-power
-	collecting (1+ (mod ind dimv) ) 
+  (setq ind (1- ind))
+  (loop for i below tensor-power
+	collecting (1+ (mod ind dimv) )
 	do (setq ind (quotient ind dimv))))
 
 
-(defun tensor-ind-to-list-ind (dimV &rest ll)
-  (sloop for m in ll
-	for i from 0 
-	summing (f* (expt  dimv i) (f1- m)) into tem
+(defun tensor-ind-to-list-ind (dimv &rest ll)
+  (loop for m in ll
+	for i from 0
+	summing (* (expt  dimv i) (1- m)) into tem
 	finally (return (1+ tem))))
 
-(defun tensor-ind-to-list-ind (dimV &rest ll)
-  (sloop for m in ll
-	for i to 0 downfrom (f1- (length ll))
-	summing (f* (expt  dimv i) (f1- m)) into tem
+(defun tensor-ind-to-list-ind (dimv &rest ll)
+  (loop for m in ll
+	for i to 0 downfrom (1- (length ll))
+	summing (* (expt  dimv i) (1- m)) into tem
 	finally (return (1+ tem))))
 
 (defun list-ind-to-tensor-ind (dimv tensor-power ind)
-  (setq ind (f1- ind))
-  (sloop for i below tensor-power
+  (setq ind (1- ind))
+  (loop for i below tensor-power
 	collecting (1+ (mod ind dimv) ) into tem
 	do (setq ind (quotient ind dimv))
 	finally (return (nreverse tem))))
@@ -445,52 +441,46 @@
 
 (defun $find_matrix_of_operator (operator basis )
   "operator acts on the space spanned by basis"
-  (let ( answer zero-b
-	 unknowns gen-a gen-sum gen-b)
+  (let (answer zero-b unknowns gen-a gen-sum gen-b)
     (setq gen-b ($firstn ($length basis) $bbbb))
     (setq gen-sum ($general_sum basis $bbbb))
     (setq answer ($fast_linsolve
-		   ($list_equations
-		     (list '(mlist)
-			   (list '(mequal)
-				 (mfuncall operator gen-sum)
-				 ($general_sum basis (setq unknowns
-							   (firstn (length basis) $aaaa))))))
-		   unknowns))
+		  ($list_equations
+		   (list '(mlist)
+			 (list '(mequal)
+			       (mfuncall operator gen-sum)
+			       ($general_sum basis (setq unknowns
+							 (subseq $aaaa 0 (length basis)))))))
+		  unknowns))
     (setq gen-a ($sublis answer unknowns))
-    (setq zero-b (sloop for w in (cdr gen-b)
-		       collecting (cons w 0)))
-    
-    
-    (sloop for v in (cdr gen-b)
-	  collecting (meval* (sublis zero-b (subst 1 v  gen-a)))
-	  into tem
-	  finally (return 
-		    ($transpose  (cons '($matrix simp) tem))))))
-	  
+    (setq zero-b (loop for w in (cdr gen-b)
+		    collecting (cons w 0)))
+
+    (loop for v in (cdr gen-b)
+       collecting (meval* (sublis zero-b (subst 1 v  gen-a)))
+       into tem
+       finally (return
+		 ($transpose  (cons '($matrix simp) tem))))))
+
 (defun $find_matrix_of_operator (operator basis &aux answer zero-b
 				 unknowns gen-a gen-sum gen-b rhs lhs eqns)
   "operator acts on the space spanned by basis"
   (setq gen-b ($firstn ($length basis) $bbbb))
   (setq gen-sum ($general_sum basis $bbbb))
   (setq lhs (mfuncall operator gen-sum))
-  (setq rhs    ($general_sum basis (setq unknowns
-							 (firstn (length basis) $aaaa))))
+  (setq rhs    ($general_sum basis (setq unknowns (subseq $aaaa 0 (length basis)))))
 
   (setq eqns ($list_equations (list '(mlist) (list '(mequal) lhs rhs))))
   (setq answer ($fast_linsolve eqns unknowns))
   (setq gen-a ($sublis answer unknowns))
-  (setq zero-b (sloop for w in (cdr gen-b)
-		     collecting (cons w 0)))
-
- 
-  (sloop for v in (cdr gen-b)
+  (setq zero-b (loop for w in (cdr gen-b) collecting (cons w 0)))
+  (loop for v in (cdr gen-b)
 	collecting (meval* (sublis zero-b (subst 1 v  gen-a)))
 	into tem
-	finally (return 
+	finally (return
 		  ($transpose  (cons '($matrix simp) tem)))))
 
-(defun $Restriction_representation (repr elt-gln vector sub-basis)
+(defun $restriction_representation (repr elt-gln vector sub-basis)
   (let ((repr-of-p ($find_matrix_of_operator `(lambda (x) (mfuncall ',repr ',elt-gln x))
 					     sub-basis)))
     (ncmul* repr-of-p vector)))
@@ -508,23 +498,23 @@
 (defun $diagonalize_torus (representation n1 n2 basis &aux diag tem mat cpoly answer eigen-values weight-vector)
   "here operator has args a and b where a is in torus and b is a sum of elements of basis"
   (setq diag ($ident n1))
-  (sloop for i from 1 to n1
-	do
- 	(setq diag ($setelmx (nth (f1- i) *some-primes* ) i i diag )))
-  
+  (loop for i from 1 to n1
+     do
+       (setq diag ($setelmx (nth (1- i) *some-primes*) i i diag)))
+
   (setq tem `(lambda (x)
 	       (mfuncall ',representation ',diag x)))
   (setq mat  ($find_matrix_of_operator tem basis))
   (setq cpoly ($charpoly mat '$x))
   (setq answer ($solve cpoly '$x) )
-  (setq eigen-values (sloop for u in (cdr answer)
-  collecting (third u)))
-  (sloop for u in eigen-values
-	collecting ($find_eigenvectors mat u) into part-basis
-	collecting (setq weight-vector (exponent-vector u n1)) into weight-vectors
-	do (show weight-vector)
-	finally (return (list '(mlist) (cons '(mlist) part-basis)
-			      (cons '(mlist) weight-vectors)))))
+  (setq eigen-values (loop for u in (cdr answer)
+			collecting (third u)))
+  (loop for u in eigen-values
+     collecting ($find_eigenvectors mat u) into part-basis
+     collecting (setq weight-vector (exponent-vector u n1)) into weight-vectors
+     do (show weight-vector)
+     finally (return (list '(mlist) (cons '(mlist) part-basis)
+			   (cons '(mlist) weight-vectors)))))
 (defun $find_eigenvectors (mat eigenvalue &aux answer eqns)
   (let* ((row-length ($length (second mat)))
 	(gen-vector ($firstn row-length $aaaa)))
@@ -541,7 +531,7 @@
 (defun $rank_of_representation (rep n1 list-of-generators &aux mat)
   (setq mat ($general_matrix n1 $cccc))
   ($find_rank_of_list_of_polynomials
-    (sloop for v in (cdr list-of-generators)
+    (loop for v in (cdr list-of-generators)
 	  appending (cdr (mfuncall rep mat v))
 	  into tem
 	  finally (return (cons '(mlist) tem)))))
@@ -549,39 +539,39 @@
 (defun $general_matrix (n a-list)
   (cond ((listp a-list)
   ($unlist_matrix_entries a-list n))
-	(t (sloop for i from 1 to n
+	(t (loop for i from 1 to n
 		 appending
-		 (sloop for j from 1 to n 
+		 (loop for j from 1 to n
 		       collecting (new-concat a-list i j))
 		 into tem
 		 finally (return ($unlist_matrix_entries (cons '(mlist ) tem) n ))))))
-		 
+
 (defun exponent-vector (n &optional (length-vector 10) &aux wnum denom num wdnom)
   (cond ((numberp n)
-  (sloop for u in *some-primes*
+  (loop for u in *some-primes*
 	for j below length-vector
 	collecting
-	(sloop for i from 1
+	(loop for i from 1
 	      when (not (zerop (mod n (expt  u i))))
-	      do (return (f1- i)))))
-	((equal (caar n) 'Rat)(setq num (second n) denom (third n))
+	      do (return (1- i)))))
+	((equal (caar n) 'rat)(setq num (second n) denom (third n))
 	 (setq wnum (exponent-vector num length-vector))
 	 (setq wdnom (exponent-vector denom length-vector))
-	 (sloop for v in wnum
+	 (loop for v in wnum
 	       for w in wdnom
-	       collecting (f- v w)))))
+	       collecting (- v w)))))
 
 
 (defun replace-parameters-by-aa (expr &aux unknowns  parameters tem1)
-  	  (setq unknowns ($list_variables expr "aa" "par"))
-	  (setq parameters (sloop for vv in (cdr unknowns)
-				 when (string-search "par" (string vv))
+	  (setq unknowns ($list_variables expr "aa" "par"))
+	  (setq parameters (loop for vv in (cdr unknowns)
+				 when (search "par" (string vv) :test #'char-equal)
 				 collecting vv))
 	  (setq tem1 (cdr $aaaa))
 
-      (sloop for vv in parameters
-	    appending (sloop while tem1
-			    when (not (memq (car tem1) unknowns ))
+      (loop for vv in parameters
+	    appending (loop while tem1
+			    when (not (member (car tem1) unknowns :test #'eq))
 			    collecting (cons vv (car tem1)) into subs1
 			    and do
 			    (let ((*print-level* 3))
@@ -599,19 +589,19 @@
 
 (defun function-denominator (pol)
   (cond ((numberp pol) (denominator pol))
-        ((polynomialp pol) 1)
+	((affine-polynomialp pol) 1)
 	((rational-functionp pol) (denom pol))
 	(t (denom (new-rat pol)))))
 
 (defun function-numerator (pol)
   (cond ((rationalp pol) (numerator pol))
-        ((polynomialp pol) pol)
+	((affine-polynomialp pol) pol)
 	((rational-functionp pol) (car pol))
 	(t (car (new-rat pol)))))
 
 (defun poly-type (x )
   (cond ((numberp x) ':number)
-	((polynomialp x) ':polynomial)
+	((affine-polynomialp x) ':polynomial)
 	((rational-functionp x) ':rational-function)
 	(($ratp x) ':$rat)
 	((and (listp x) (eq (caar x) 'rat)) ':rat)
@@ -623,11 +613,11 @@
     (check-vgp-correspond)))
 
 (defun check-vgp-correspond()
-  (sloop for v in varlist
+  (loop for v in varlist
 	for w in genvar
 	when (or (not (equal v (get w 'disrep)))
-    	         (not (eq w (get-genvar v))))
-       do (ferror "bad ~A and ~A" v w)))
+		 (not (eq w (get-genvar v))))
+       do (merror "bad ~A and ~A" v w)))
 
 
 (defun $slow_gcdlist (&rest ll)
@@ -650,16 +640,16 @@
 ;	  (,1 (car ,rest-arg))
 ;	  (otherwise (apply ',new-funct (,binary-op (first ,rest-arg)
 ;					   (second ,rest-arg)) (cddr ,rest-arg)))))))
-	     
 
-  
+
+
 ;(defmacro polyop (x y identity-x identity-y number-op poly-op rat-op &optional rat-switch )
 ;  (cond (rat-switch (setq rat-switch '(t))))
 ;  `(cond
 ;     ((and (numberp ,x)(numberp ,y))(,number-op ,x ,y))
 ;     ((eq ,x ,identity-x) ,y)
 ;     ((eq ,y ,identity-y) ,x)
-;     (t 
+;     (t
 ;      (let ((xx (poly-type ,x)) answer
 ;	    (yy (poly-type ,y)))
 ;
@@ -669,7 +659,7 @@
 ;	       (setq ,x (cdr ,x) xx ':rational-function))
 ;	      ((eq xx ':rat ) (setq ,x (cons (second ,x) (third ,x))
 ;				   xx ':rational-function)))
-;	       
+;
 ;	(cond
 ;	  ((null yy)(setq ,y (cdr ($new_rat ,y)) yy ':rational-function))
 ;	  ((eq yy ':$rat)(setq ,y (cdr ,y) yy ':rational-function))
@@ -691,15 +681,15 @@
 ;		   (:number (,poly-op ,x ,y))
 ;		   (:polynomial (,poly-op ,x ,y))
 ;		   (:rational-function (,rat-op (cons ,x 1) ,y,@ rat-switch))
-;		   (otherwise (ferror "unknown type for polyop "))))
+;		   (otherwise (merror "unknown type for polyop "))))
 ;		(:rational-function
 ;		 (case yy
 ;		   (:number (,rat-op ,x  (cons ,y 1) ,@ rat-switch))
 ;		   (:polynomial (,rat-op ,x (cons ,y 1)  ,@ rat-switch))
 ;		   (:rational-function (,rat-op ,x ,y ,@ rat-switch))))
-;		(otherwise (ferror "unknown arg"))))
-;	(cond ((polynomialp answer) answer)
-;	      ((rational-functionp answer)	
+;		(otherwise (merror "unknown arg"))))
+;	(cond ((affine-polynomialp answer) answer)
+;	      ((rational-functionp answer)
 ;	       (cond ((eq 1 (cdr answer))(car answer))
 ;		     (t answer)))
 ;	      (t answer))))))
@@ -733,9 +723,9 @@
 ;	     (:rational-function
 ;	      (cond (($numberp expr)
 ;		     (cond ((zerop (num expr) 0))
-;			   (t 
+;			   (t
 ;		     (list '(rat simp) (num expr) (denom expr)))))
-;		    (t 
+;		    (t
 ;		     ($ratdisrep (header-poly expr)))))
 ;	     (otherwise  (cond ((mbagp expr)(cons (car expr) (mapcar 'new-disrep expr)))
 ;			       (($ratp expr)($ratdisrep expr))
@@ -758,7 +748,7 @@
 (defun sp-mul* (&rest a-list)
   (let ((varlist ))
     (cond ((< (length a-list) 3)(apply 'mul* a-list))
-   	  (t (sp-mul* (car a-list) (apply 'sp-mul* (cdr a-list)))))))
+	  (t (sp-mul* (car a-list) (apply 'sp-mul* (cdr a-list)))))))
 
 (defun sp-div* (a b)
   (let ((varlist))
@@ -787,22 +777,22 @@
 (defun poly-scalarp (a &aux tem)
   (cond ((numberp a))
 	((atom a)($scalarp a))
-	((setq tem(polynomialp a)) ($scalarp tem))
-	((and (setq tem(polynomialp (car a))) (polynomialp (cdr a)))
+	((setq tem(affine-polynomialp a)) ($scalarp tem))
+	((and (setq tem(affine-polynomialp (car a))) (affine-polynomialp (cdr a)))
 	 ($scalarp tem))))
-	 
-	     
+
+
 (defun $coefficient_matrix (a-list variables)
   (check-arg a-list  '$listp nil)
   (check-arg variables  '$listp nil)
-  (sloop for w in (cdr a-list)
+  (loop for w in (cdr a-list)
 	collecting
-	(sloop for v in (cdr variables)
+	(loop for v in (cdr variables)
 	      collecting
-	      ($nc_coeff w v) into tem 
+	      ($nc_coeff w v) into tem
 	      finally (return (cons '(mlist) tem)))
-        into bil
-	finally (return (cons '($matrix) bil))))  
+	into bil
+	finally (return (cons '($matrix) bil))))
 ;
 ;
 ;
@@ -813,12 +803,12 @@
 ;
 ;
 ;
-;(DEFMFUN new-RATREP* (X) 
+;(DEFMFUN new-RATREP* (X)
 ;  (LET ()					; (GENPAIRS)
 ;;	    (ORDERPOINTER VARLIST)  ;;creates enough new genvar and numbers them done
 ;    (RATSETUP1 VARLIST GENVAR)
 ;    ;which is now in new-ratf
-;    
+;
 ;    (MAPC #'(LAMBDA (Y Z) (cond ((assolike y genpairs)  nil)
 ;				(t (PUSH (CONS Y (RGET Z)) GENPAIRS))))
 ;	  VARLIST GENVAR)
@@ -826,15 +816,15 @@
 ;    (RATSETUP2 VARLIST GENVAR)
 ;    (XCONS (PREP1 X)				; PREP1 changes VARLIST
 ;	   (LIST* 'MRAT 'SIMP VARLIST GENVAR	;    when $RATFAC is T.
-;		  (IF (AND (NOT (ATOM X)) (MEMQ 'IRREDUCIBLE (CDAR X)))
+;		  (IF (AND (NOT (ATOM X)) (MEMber 'IRREDUCIBLE (CDAR X) :test #'eq))
 ;		      '(IRREDUCIBLE))))))
 ;
-;(DEFMFUN new-RATREP* (X) 
+;(DEFMFUN new-RATREP* (X)
 ;  (LET ()					; (GENPAIRS)
 ;;	    (ORDERPOINTER VARLIST)  ;;creates enough new genvar and numbers them done
 ;    (RATSETUP1 VARLIST GENVAR)
 ;    ;which is now in new-ratf
-;;      
+;;
 ;;    (MAPC #'(LAMBDA (Y Z) (cond ((assolike y genpairs)  nil)           ;;do this in new
 ;;				(t (PUSH (CONS Y (RGET Z)) GENPAIRS))))
 ;;	  VARLIST GENVAR)
@@ -842,7 +832,7 @@
 ;    (RATSETUP2 VARLIST GENVAR)
 ;    (XCONS (PREP1 X)				; PREP1 changes VARLIST
 ;	   (LIST* 'MRAT 'SIMP VARLIST GENVAR	;    when $RATFAC is T.
-;		  (IF (AND (NOT (ATOM X)) (MEMQ 'IRREDUCIBLE (CDAR X)))
+;		  (IF (AND (NOT (ATOM X)) (MEMber 'IRREDUCIBLE (CDAR X) :test #'eq))
 ;		      '(IRREDUCIBLE))))))
 ;
 ;(Defun New-RATF (L &aux tem)
@@ -851,7 +841,7 @@
 ;	  (SETQ *WITHINRATF* T)
 ;	  (WHEN (EQ '%% (CATCH 'RATF (new-NEWVAR L)))
 ;	    (SETQ *WITHINRATF* NIL) (RETURN (SRF L)))
-;	  (sloop for v in varlist
+;	  (loop for v in varlist
 ;		for i from 1
 ;		when  (setq tem (get-genvar v))
 ;		collecting tem into a-list
@@ -863,7 +853,7 @@
 ;		       (push (cons v (rget tem)) genpairs )
 ;		       )
 ;		into a-list
-;		do (set tem i)
+;		do (setf (symbol-value tem) i)
 ;		finally (setq genvar a-list))
 ;	  (SETQ U (CATCH 'RATF (new-RATREP* L)))	; for truncation routines
 ;	  (RETURN (OR U (PROG2 (SETQ *WITHINRATF* NIL) (SRF L)))))))
@@ -881,7 +871,7 @@
   (cond
     ((and ($ratp expr)(equal *genvar* (genvar expr))(equal *varlist* (varlist expr)))
      expr)
-    (($ratp expr)(cond ((sloop for v in (varlist expr)   ;;what about minimize varlist here.
+    (($ratp expr)(cond ((loop for v in (varlist expr)   ;;what about minimize varlist here.
 			      for w in (genvar expr)	;or in new-ratf
 			      when
 			      (not (eq w (get-genvar v)))
@@ -889,24 +879,24 @@
 			      (return 'bad-order))
 			(new-ratf expr))
 		       (t expr)))
-    ((mbagp expr) (CONS (CAR EXPr) (MAPCAR #'$new_RAT (CDR EXPr))) ($new_RAT EXPr))
+    ((mbagp expr) (cons (car expr) (mapcar #'$new_rat (cdr expr))) ($new_rat expr))
     ((and (not (atom expr))(not (atom (car expr))))(cond ((equal (caar expr) 'rat) expr)
 							 (t (new-ratf expr))))
-						       
+
     (t (new-ratf expr))))
-;(IF (MBAGP EXP) (CONS (CAR EXP) (MAPCAR #'RAT0 (CDR EXP))) (RATF EXP))) 
+;(if (mbagp exp) (cons (car exp) (mapcar #'rat0 (cdr exp))) (ratf exp)))
 
 
 (defun $shift (expr &optional (variables $current_variables) &aux tem)
- (sublis  (sloop for v on (cdr variables)
+ (sublis (loop for v on (cdr variables)
 	when (second v)
 	do (setq tem  (second v))
 	else do (setq tem (second variables))
-		      
+
 	collecting (cons (car v) tem)) expr))
 (defun $spur (expr function n &aux (tem expr) (answer 0))
-  (sloop for i below n
-	do 
+  (loop for i below n
+	do
 	(setq answer (add* answer (setq tem (funcall function tem)))))
  ($ratsimp answer))
 
@@ -914,42 +904,40 @@
 (defun $basis_of_invariant_ring (n &optional (variables $current_variables) &aux
 				 monoms trace_monoms f new-f eqns solns tem ar sp pivots)
      (setq monoms ($mono variables n))
-	(setq trace_monoms (sloop for u in (cdr monoms)
-			    collecting ($spur u '$shift (f1- (length variables)) ) into tem
+	(setq trace_monoms (loop for u in (cdr monoms)
+			    collecting ($spur u '$shift (1- (length variables)) ) into tem
 			    finally (return (cons '(mlist ) tem))))
 	(break t)
 	(setq f ($general_sum trace_monoms $aaaa))
 	(setq new-f ($dotsimp f))
 	(setq eqns ($extract_linear_equations (list '(mlist) new-f) monoms))
-	(setq solns ($fast_linsolve eqns (firstn (length monoms) $aaaa)))
+	(setq solns ($fast_linsolve eqns (subseq $aaaa 0 (length monoms))))
 	(setq sp(send $poly_vector :the-sparse-matrix))
     (setq ar (send sp ':column-used-in-row))
-   (setq pivots  (sloop for i below (length (the cl:array ar))
+   (setq pivots (loop for i below (length (the cl:array ar))
 	  when (setq tem (aref ar i))
 	  collecting tem into tem1
 	  finally (return  tem1)))
-   (sloop 	 for i in pivots
-		 collecting (nth (f1+ i) trace_monoms)
+   (loop for i in pivots
+		 collecting (nth (1+ i) trace_monoms)
 		 into tem1
-		 finally (return (cons '(mlist ) tem1)))) 
+		 finally (return (cons '(mlist) tem1))))
 
-  
-
-
-(defvar $mmm )
+(defvar $mmm)
 (defvar $conditions_on_q nil)
+
 (defun $case_rep (mat vect triple  &aux  answer  subs ($expop 100)
 		 ind-used vmmm prod mat.rtx relat-mat)
   (setq triple (cdr triple))
   (setq subs (list (cons '$%alpha (first triple))
 		   (cons '$%beta (second triple))
 		   (cons '$%gamma (third triple))))
-  
+
   (let ((mmm (sublis subs $mmm)))
     (setq mmm ($ratsimp mmm))
     (displa mmm)
-    (sloop for  v in (cdr $conditions_on_q)
-	  for i from 1 
+    (loop for  v in (cdr $conditions_on_q)
+	  for i from 1
 	  when ($zerop ($ratsimp (sublis subs v)))
 	  collecting (nth i mmm) into tem
 	  and
@@ -958,23 +946,23 @@
     (format t "~%Dimension of representation is ~A." (length ind-used))
     (show ind-used)
     (setq vmmm
-	  (sloop for i from 1 to (length ind-used)
-		collecting (mul* (nth i vect)(nth (f1- i) relat-mat)) into tem
+	  (loop for i from 1 to (length ind-used)
+		collecting (mul* (nth i vect)(nth (1- i) relat-mat)) into tem
 		finally (return (meval* (cons '(mplus) tem)))))
-    (setq mat.rtx (ncmul* mat '(($MATRIX SIMP)
-				((MLIST SIMP) $X) ((MLIST SIMP) $Y) ((MLIST SIMP) $Z))))
-    
+    (setq mat.rtx (ncmul* mat '(($matrix simp)
+				((mlist simp) $x) ((mlist simp) $y) ((mlist simp) $z))))
+
     (setq prod
 	  (ncmul*  ($transpose mat)
-		   ($sub_list `((MLIST SIMP) ((MEQUAL SIMP) (($MATRIX SIMP)
-							     ((MLIST SIMP) $X)
-							     ((MLIST SIMP) $Y)
-							     ((MLIST SIMP) $Z))
+		   ($sub_list `((mlist simp) ((mequal simp) (($matrix simp)
+							     ((mlist simp) $x)
+							     ((mlist simp) $y)
+							     ((mlist simp) $z))
 					      ,mat.rtx)) vmmm) mat))
     (setq answer (mfuncall '$cof prod))
-    (sloop for i in ind-used
+    (loop for i in ind-used
 	  collecting (nth i answer) into tem
 	  finally (return (cons '(mlist) tem)))))
+
 (defun $make_commutative (expr)
   (resimplify (subst 'mtimes 'mnctimes expr)))
-
