@@ -23,7 +23,7 @@
 ;;****************************************************************************
 ;;Generatig MathML presenation codes for the expr 
 ;;This is a maxima top-level function used  the form
-;;              prmathml(expr, [,filename[,t (d)]])  on the C-line
+;;              prmathml(expr, [,(filename|stream)[,t (d)]])  on the C-line
 
 (defmfun $prmathml (&rest margs)
          (prog (ccol *row* *indent* filename mexplabel mexpress mPrport x y)
@@ -33,12 +33,17 @@
              ((null mexpress) (princ " NO EXPRESSION GIVEN ")
               (return nil))
              ((null (cdr margs)) (setq filename nil) (setq mPrport t))
-             ((null (cddr margs)) (setq filename (cadr margs))
+             ((null (cddr margs))
               (setq mPrport
-                    (open (fullstrip1 (cadr margs))
-                        :direction :output 
-                        :if-exists :append
-                        :if-does-not-exist :create)))
+                    (if (stringp (cadr margs))
+                      (progn
+                        (setq filename (cadr margs))
+                        (open (cadr margs)
+                            :direction :output 
+                            :if-exists :append
+                            :if-does-not-exist :create))
+                      ;; otherwise, assume (cadr margs) is a stream.
+                      (cadr margs))))
              (t (princ " wrong No. of Arguments given ")))
            (cond
              ((member mexpress $labels :test #'eq)
@@ -247,6 +252,14 @@
   (mPr_engine (cadr mexpress) 'mparen 'mparen)
   (tprinc "<mo>|</mo>"))
 
+(defun mPr-conjugate (mexpress)
+  (tprinc "<mover>")
+  (tprinc "<mrow>")
+  (mPr_engine (cadr mexpress) 'mparen 'mparen)
+  (tprinc "</mrow>")
+  (tprinc "<mo>&#xaf;</mo>") ;; macron
+  (tprinc "</mover>"))
+
 ;; a[1]^2 or a[x,y]^z
 (defun mPr-arr-power(b e)
   (tprinc "<msubsup>")
@@ -284,7 +297,7 @@
   (tprinc "</msub>") (row-end "</mrow>")
 )
 ;;      in mPr_engine ,whennever mexpress is an atom this function taking care 
-;;of it by getting a TeX symbol if it exsits. Also it handles some word wich
+;;of it by getting a TeX symbol if it exists. Also it handles some word which
 ;;has a reserved character for TeX
 
 ;; prints instead of returning value now
@@ -472,6 +485,11 @@
   (tprinc "<mo>&ApplyFunction;</mo>")
   (mPr-listparen (cdr mexpress)))
 
+(defun mPr-gamma (mexpress)
+  (mPr_engine '|$Gamma| 'mparen 'mparen) ;; ensure big gamma instead of little gamma (CHCHR property)
+  (tprinc "<mo>&ApplyFunction;</mo>")
+  (mPr-listparen (cdr mexpress)))
+
 ;;      for infix operator , and also handle when there is a truncation
 ;;in macsyma expression (see mPr-infix1)
 ;;      mPr-infix calling
@@ -538,8 +556,13 @@
      (row-begin "<mrow>")(tprinc "<mo>&Integral;</mo>"))
     ((equal (length mexpress) 5)
      (row-begin "<mrow>")(tprinc "<msubsup><mo>&Integral;</mo>")
-     (mPr_engine (cadddr mexpress) 'mparen 'mparen) (tprinc "  ")
+     (row-begin "<mrow>")
+     (mPr_engine (cadddr mexpress) 'mparen 'mparen)
+     (row-end "</mrow>")
+     (tprinc "  ")
+     (row-begin "<mrow>")
      (mPr_engine (car (cddddr mexpress)) 'mparen 'mparen)
+     (row-end "</mrow>")
      (tprinc "</msubsup>"))
     (t (merror "Wrong NO. of Arguments")))
   (row-begin "<mrow>")
@@ -608,12 +631,13 @@
   (let (r firstpart exponent)
     (cond
       ((integerp atom) (tprinc "<mn>") (tprinc atom) (tprinc "</mn>"))
-      (t (setq r (explode atom))
-         (setq exponent (member 'e r :test #'eq))
+      (t (setq r (exploden atom))
+         ;; Hmm. What if the exponent marker is something other than 'e' or 'E' ??
+         (setq exponent (or (member #\e r :test #'eq) (member #\E r :test #'eq)))
          (cond
            ((null exponent) (tprinc "<mn>") (tprinc atom) (tprinc "</mn>"))
            (t (setq firstpart
-                    (nreverse (cdr (member 'e (reverse r) :test #'eq))))
+                    (nreverse (cdr (or (member #\e (reverse r) :test #'eq) (member #\E (reverse r) :test #'eq)))))
               (tprinc "<mn>") 
 	      (mapc #'tpchar firstpart) (tprinc "</mn>") 
 	      (tprinc "<mo>&CenterDot;</mo><msup><mn>10</mn> <mn>")
@@ -727,6 +751,25 @@
 (defun mPr-times (mexpress)
   (let ((lop 'mtimes) (rop 'mtimes)) (mPr-infix mexpress)))
 
+(defun mathml-presentation-lambda (mexpress)
+  (let
+    ((op (caar mexpress))
+     (args (cdr (cadr mexpress)))
+     (body (cddr mexpress)))
+    (mPr_engine op 'mparen 'mparen)
+    (if (= (length args) 1)
+      (mPr_engine (car args) 'mparen 'mparen)
+      (mPr-listparen args))
+    (mPr_engine "." 'mparen 'mparen)
+    (if (= (length body) 1)
+      (mPr_engine (car body) 'mparen 'mparen)
+      (mPr-listparen body))))
+
+;; An improvement on the default, but not much.
+;; Could benefit from just a little more attention.
+(defun mathml-presentation-buildinfo (mexpress)
+  (mPr_engine `(($matrix) ,@(mapcar #'(lambda (e) `((mlist) ,e)) (cdr mexpress))) 'mparen 'mparen))
+
 ;;;;;;; Operators
 
 (setup '(mlist (mPrprocess mPr-list)))
@@ -778,6 +821,8 @@
 
 (setup '(%abs (mPrprocess mPr-abs)))
 
+(setup '($conjugate (mPrprocess mPr-conjugate)))
+
 (setup '(mnctimes (mPrprocess mPr-infix) (mPr-lbp 110) (mPr-rbp 109)
             (chchr "&CenterDot;")))
 
@@ -860,6 +905,10 @@
 
 (setup '($matrix (mPrprocess mPr-matrix)))
 
+(setup '(lambda (mPrprocess mathml-presentation-lambda)))
+
+(setup '(%build_info (mPrprocess mathml-presentation-buildinfo)))
+
 (setup '($%pi (chchr "&pi;")))
 
 (setup '($%e (chchr "&ee;")))
@@ -906,6 +955,10 @@
 (setf (get '$beta 'chchr) '"&beta;")
 (setf (get '$gamma 'chchr) '"&gamma;")
 (setf (get '%gamma 'chchr) '"&gamma;")
+(setf (get '%gamma_incomplete 'chchr) '"&Gamma;")
+(setf (get '%gamma_incomplete_generalized 'chchr) '"&Gamma;")
+(setf (get '%gamma_incomplete_regularized 'chchr) '"Q")
+(setf (get '$gamma_greek 'chchr) '"&gamma;")
 (setf (get '$delta 'chchr) '"&delta;")
 (setf (get '$epsilon 'chchr) '"&epsilon;")
 (setf (get '$varepsilon 'chchr) '"&varepsilon;")
@@ -1026,6 +1079,8 @@
 (setup '($acsch (mPrprocess mPr-function) (mPr-rbp 110) (chchr"acsch")))
 (setup '($ln (mPrprocess mPr-function) (mPr-rbp 110) (chchr"ln")))
 (setup '($log (mPrprocess mPr-function) (mPr-rbp 110) (chchr"log")))
+(setup '(%gamma (mPrprocess mPr-gamma)))
+
 ;;
 ;;
 ;;      set the preference feature
@@ -1040,6 +1095,12 @@
 (setq $mPrautolabel nil) ;set autolabel mode off, can be set to be integer
 (setq $lamPrautolabel nil)      ;set LaTeX autolabel mode false
 
+;; The MathML presentation code has been loaded. Run each post-load hook. This
+;; let other libraries hook in to the MathML library easily (doing so needs
+;; SETUP and MPR_ENGINE to be defined).
+;;
+;; Each hook should be an idempotent thunk.
 
-
-
+(when (boundp '*mathml-presentation-hook*)
+  (dolist (hook (symbol-value '*mathml-presentation-hook*))
+    (funcall hook)))
