@@ -12,7 +12,7 @@
   (member x lis :test #'eq))
 
 ;;this will make operators which declare the type and result of numerical operations
-(eval-when (:compile-toplevel :load-toplevel)
+(eval-when (:compile-toplevel :load-toplevel :execute)
 
   (defmacro def-op (name arg-type op &optional return-type)
     `(setf (macro-function ',name)
@@ -136,8 +136,8 @@
 	((symbolp x)
 	 (cond ((or (numberp y) (stringp y)) nil)
 	       ((symbolp y)
-		(let ((nx (symbol-name x))
-		      (ny (symbol-name y)))
+		(let ((nx (print-invert-case x))
+		      (ny (print-invert-case y)))
 		  (declare (string nx ny))
 		  (cond ((string<$ nx ny)
 			 t)
@@ -173,6 +173,7 @@
 (defun firstn (n lis)
   (subseq lis 0 n))
 
+(declaim (inline fixnump))
 (defun fixnump (n)
   (typep n 'fixnum))
 
