@@ -1015,25 +1015,38 @@ TDNEG TDZERO TDPN) to store it, and also sets SIGN."
 
 ;; Other than sums, products, and lambda forms, meqp knows nothing
 ;; about dummy variables. Because of the way niceindices chooses names
-;; for the sum indicies, it's necessary to locally assign a new value to
+;; for the sum indices, it's necessary to locally assign a new value to
 ;; niceindicespref.
 
 (defun meqp-by-csign (z a b)
-  (let ((sgn) (rsgn) (isgn) ($niceindicespref `((mlist) ,(gensym) ,(gensym) ,(gensym))))
+  (let (($niceindicespref `((mlist) ,(gensym) ,(gensym) ,(gensym))))
     (setq z ($niceindices z))
     (setq z (if ($constantp z) ($rectform z) (sratsimp z)))
-    (setq sgn ($csign z))
-    (cond ((eq '$zero sgn) t)
-	  ((memq sgn '($pos $neg $pn)) nil)
+    (let ((sgn ($csign z))
+          (dunno `(($equal) ,a ,b)))
+      (cond ((eq '$zero sgn) t)
+            ((memq sgn '($pos $neg $pn)) nil)
 
-	  ((memq sgn '($complex $imaginary)) ;; previously checked also for (linearp z '$%i))
-	   (setq rsgn ($csign ($realpart z)))
-	   (setq isgn ($csign ($imagpart z)))
-	   (cond ((and (eq '$zero rsgn) (eq '$zero isgn)) t)
-		 ((or (memq rsgn '($neg $pos $pn)) (memq isgn '($neg $pos $pn))) nil)
-		 (t `(($equal) ,a ,b))))
+            ;; previously checked also for (linearp z '$%i))
+            ((memq sgn '($complex $imaginary))
+             ;; We call trisplit here, which goes back to general evaluation and
+             ;; could cause an infinite recursion. To make sure that doesn't
+             ;; happen, use the with-safe-recursion macro.
+             (handler-case
+                 (with-safe-recursion meqp-by-csign z
+                   (let* ((ri-parts (trisplit z))
+                          (rsgn ($csign (car ri-parts)))
+                          (isgn ($csign (cdr ri-parts))))
+                     (cond ((and (eq '$zero rsgn)
+                                 (eq '$zero isgn)) t)
 
-	  (t `(($equal) ,a ,b)))))
+                           ((or (memq rsgn '($neg $pos $pn))
+                                (memq isgn '($neg $pos $pn))) nil)
+
+                           (t dunno))))
+               (unsafe-recursion () dunno)))
+
+            (t dunno)))))
 
 ;; For each fact of the form equal(a,b) in the active context, do e : ratsubst(b,a,e).
 
@@ -1248,20 +1261,13 @@ TDNEG TDZERO TDPN) to store it, and also sets SIGN."
 		(setq exp dum)))
 	   ((eq dum 'float)
 	    (if (and (setq dum (numer x)) (numberp dum)) (setq exp dum)))
-           ;; If numer or symbol, try to evaluate numerically. NUMER returns NIL
-           ;; catches any errors and returns nil. If there would have been a
-           ;; floating point overflow, we might end up with a bigfloat. In that
-           ;; case, or if the result is small enough that we don't really trust
-           ;; it (eek, hack!), try evaluating as a bigfloat.
 	   ((and (member dum '(numer symbol) :test #'eq)
 		 (prog2 (setq dum (numer x))
 		     (or (null dum)
-                         (bigfloatp dum)
 			 (and (numberp dum)
 			      (prog2 (setq exp dum)
 				  (< (abs dum) 1.0e-6))))))
-	    (cond ((bigfloatp dum) (setq exp dum))
-                  ($signbfloat
+	    (cond ($signbfloat
 		   (and (setq dum ($bfloat x)) ($bfloatp dum) (setq exp dum)))
 		  (t (setq sign '$pnz evens nil odds (ncons x) minus nil)
 		     (return sign)))))
@@ -1336,7 +1342,7 @@ TDNEG TDZERO TDPN) to store it, and also sets SIGN."
 	 (funcall (get (mop (mop x)) 'sign-function) x))
 	((specrepp x) (sign (specdisrep x)))
 	((kindp (caar x) '$posfun) (sign-posfun x))
-	((and (kindp (caar x) '$oddfun) (kindp (caar x) '$increasing)) (sign-oddinc x))
+	((kindp (caar x) '$oddfun) (sign-oddfun x))
 	(t (sign-any x))))
 
 (defun sign-any (x)
@@ -1374,7 +1380,7 @@ TDNEG TDZERO TDPN) to store it, and also sets SIGN."
     (sign1 (car x))
     (cond ((eq sign '$zero) (return t))
 	  ((and *complexsign* (eq sign '$complex))
-	   ;; Found a complex factor. Return immediatly. The sign is $complex.
+	   ;; Found a complex factor. Return immediately. The sign is $complex.
 	   (return t))
 	  ((and *complexsign* (eq sign '$imaginary))
 	   ;; Found an imaginary factor. Look if we have already one.
@@ -1426,6 +1432,11 @@ TDNEG TDZERO TDPN) to store it, and also sets SIGN."
                   (kindp (caar lhs) '$increasing))
              (sign (sub (cadr lhs) (cadr rhs)))
              t)
+            ((and (not (atom lhs)) (not (atom rhs))
+                  (eq (caar lhs) (caar rhs))
+                  (kindp (caar lhs) '$decreasing))
+             (sign (sub (cadr rhs) (cadr lhs)))
+             t)
             ((and (not (atom lhs)) (eq (caar lhs) 'mabs)
                   (alike1 (cadr lhs) rhs))
              (setq sign '$pz minus nil odds nil evens nil) t)
@@ -1613,10 +1624,10 @@ TDNEG TDZERO TDPN) to store it, and also sets SIGN."
 	     (format t "~&in SIGN-MEXPT for ~A, base is $imaginary.~%" x))
 	   (cond
 	     ((and (integerp expt) (eq evod '$even))
-	      (setq sign (if (eq (mod expt 4) 0) '$pz '$nz)))
+	      (setq sign (if (eql (mod expt 4) 0) '$pz '$nz)))
 	     ((and (integerp expt) (eq evod '$odd))
 	      (setq sign '$imaginary
-		    minus (if (eq (mod (- expt 1) 4) 0) t nil)))
+		    minus (if (eql (mod (- expt 1) 4) 0) t nil)))
 	     (t (setq sign '$complex))))
 
 	  ((and (eq sign-base '$zero)
@@ -1813,8 +1824,19 @@ TDNEG TDZERO TDPN) to store it, and also sets SIGN."
 	odds nil
 	evens nil))
 
-(defun sign-oddinc (x)
-  (sign (cadr x)))
+(defun sign-oddfun (x)
+  (cond ((kindp (caar x) '$increasing)
+         ; Take the sign of the argument
+         (sign (cadr x)))
+        ((kindp (caar x) '$decreasing)
+         ; Take the sign of negative of the argument
+         (sign (neg (cadr x))))
+        (t
+         ; If the sign of the argument is zero, then we're done (the sign of
+         ; the function value is the same).  Otherwise, punt to SIGN-ANY.
+         (sign (cadr x))
+         (unless (eq sign '$zero)
+           (sign-any x)))))
 
 (defun imag-err (x)
   (if sign-imag-errp
